==> admin-cli-4.0-b33-sources.jar: com/sun/enterprise/admin/cli/DirectoryClassLoader.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.admin.cli;

import java.io.*;
import java.net.*;
import java.util.*;

import com.sun.enterprise.universal.i18n.LocalStringsImpl;

/**
 * A class loader that loads classes from all jar files
 * in a specified directory.
 */
public class DirectoryClassLoader extends URLClassLoader {
    private static final LocalStringsImpl strings =
            new LocalStringsImpl(DirectoryClassLoader.class);

    /**
     * Create a DirectoryClassLoader to load from jar files in
     * the specified directory, with the specified parent class loader.
     *
     * @param dir the directory of jar files to load from
     * @param parent the parent class loader
     * @throws IOException if the directory can't be accessed
     */
    public DirectoryClassLoader(String dir, ClassLoader parent)
                        throws IOException {
        super(getJars(new File(dir)), parent);
    }

    /**
     * Create a DirectoryClassLoader to load from jar files in
     * the specified directory, with the specified parent class loader.
     *
     * @param dir the directory of jar files to load from
     * @param parent the parent class loader
     * @throws IOException if the directory can't be accessed
     */
    public DirectoryClassLoader(File dir, ClassLoader parent)
                        throws IOException {
        super(getJars(dir), parent);
    }

    private static URL[] getJars(File dir) throws IOException {
        File[] fjars = dir.listFiles(new FilenameFilter() {
            public boolean accept(File dir, String name) {
                return name.endsWith(".jar");
            }
        });
        if (fjars == null)
            throw new IOException(strings.get("DirError", dir));
        URL[] jars = new URL[fjars.length];
        for (int i = 0; i < fjars.length; i++)
            jars[i] = fjars[i].toURI().toURL();
        return jars;
    }
}

==> admin-cli-5.0-sources.jar: com/sun/enterprise/admin/cli/DirectoryClassLoader.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.admin.cli;

import java.io.*;
import java.net.*;
import java.util.*;

import com.sun.enterprise.universal.i18n.LocalStringsImpl;

/**
 * A class loader that loads classes from all jar files
 * in a specified directory.
 */
public class DirectoryClassLoader extends URLClassLoader {
    private static final LocalStringsImpl strings =
            new LocalStringsImpl(DirectoryClassLoader.class);

    /**
     * Create a DirectoryClassLoader to load from jar files in
     * the specified directory, with the specified parent class loader.
     *
     * @param dir the directory of jar files to load from
     * @param parent the parent class loader
     * @throws IOException if the directory can't be accessed
     */
    public DirectoryClassLoader(String dir, ClassLoader parent) throws IOException {
        super(getJars(new File(dir)), parent);
    }
    
    public DirectoryClassLoader(Set<File> jarsAndDirs, ClassLoader parent) throws IOException {
        super(getJars(jarsAndDirs), parent);
    }

    /**
     * Create a DirectoryClassLoader to load from jar files in
     * the specified directory, with the specified parent class loader.
     *
     * @param dir the directory of jar files to load from
     * @param parent the parent class loader
     * @throws IOException if the directory can't be accessed
     */
    public DirectoryClassLoader(File dir, ClassLoader parent)
                        throws IOException {
        super(getJars(dir), parent);
    }
    
    private static URL[] getJars(Set<File> jarsAndDirs) throws IOException {
        if (jarsAndDirs == null) {
            throw new IOException(strings.get("DirError", ""));
        }
        Collection<URL> result = new ArrayList<URL>();
        for (File jd : jarsAndDirs) {
            if (jd.isDirectory()) {
                result.addAll(Arrays.asList(getJars(jd)));
            } else {
                result.add(jd.toURI().toURL());
            }
        }
        return result.toArray(new URL[result.size()]);
    }

    private static URL[] getJars(File dir) throws IOException {
        File[] fjars = dir.listFiles(new FilenameFilter() {
            public boolean accept(File dir, String name) {
                return name.endsWith(".jar");
            }
        });
        if (fjars == null)
            throw new IOException(strings.get("DirError", dir));
        URL[] jars = new URL[fjars.length];
        for (int i = 0; i < fjars.length; i++)
            jars[i] = fjars[i].toURI().toURL();
        return jars;
    }
}
